# Classeviva.py
[`Python`](https://python.org) [`API wrapper`](https://rapidapi.com/blog/api-glossary/api-wrapper/) per [`Classeviva`](https://web.spaggiari.eu/) (registro elettronico di [`GruppoSpaggiariParma`](https://web.spaggiari.eu/www/app/default/index.php))

# Documentazione
La [`documentazione italiana`](https://readthedocs.org/projects/classeviva/) si trova su [`ReadTheDocs.io`](https://readthedocs.org)

# Contributi
Il codice sorgente può essere modificato su [`GitHub Dev`](https://github.dev) con l'[`editor della repository`](https://github.dev/Lioydiano/Classeviva)

# Pacchetto
Il pacchetto può essere scaricato da [`PyPI`](https://pypi.org) tramite `pip`, il progetto si trova [`qui`](https://pypi.org/project/Classeviva.py/)

# API REST
L'`API REST` si trova a [`web.spaggiari.eu/rest`](https://web.spaggiari.eu/rest/), la documentazione si trova [su `GitHub`](https://github.com/Lioydiano/Classeviva-Official-Endpoints)
